@@ -141,6 +141,7 @@ function pushCommonFlags(flags: string[], options: CommonOptions, keys: OptionKe
   let jsxFactory = getFlag(options, keys, 'jsxFactory', mustBeString);
   let jsxFragment = getFlag(options, keys, 'jsxFragment', mustBeString);
   let define = getFlag(options, keys, 'define', mustBeObject);
+  let logOverride = getFlag(options, keys, 'logOverride', mustBeObject);
   let pure = getFlag(options, keys, 'pure', mustBeArray);
   let keepNames = getFlag(options, keys, 'keepNames', mustBeBoolean);
 
@@ -176,6 +177,12 @@ function pushCommonFlags(flags: string[], options: CommonOptions, keys: OptionKe
       flags.push(`--define:${key}=${define[key]}`);
     }
   }
+  if (logOverride) {
+    for (let key in logOverride) {
+      if (key.indexOf('=') >= 0) throw new Error(`Invalid log override: ${key}`);
+      flags.push(`--log-override:${key}=${logOverride[key]}`);
+    }
+  }
   if (pure) for (let fn of pure) flags.push(`--pure:${fn}`);
   if (keepNames) flags.push(`--keep-names`);
 }
