@@ -632,112 +632,7 @@ func validateDefines(
 func validateLogOverrides(input map[string]LogLevel) (output map[logger.MsgID]logger.LogLevel) {
 	output = make(map[uint8]logger.LogLevel)
 	for k, v := range input {
-		logLevel := validateLogLevel(v)
-
-		switch k {
-		// JS
-		case "assign-to-constant":
-			output[logger.MsgID_JS_AssignToConstant] = logLevel
-		case "call-import-namespace":
-			output[logger.MsgID_JS_CallImportNamespace] = logLevel
-		case "commonjs-variable-in-esm":
-			output[logger.MsgID_JS_CommonJSVariableInESM] = logLevel
-		case "delete-super-property":
-			output[logger.MsgID_JS_DeleteSuperProperty] = logLevel
-		case "direct-eval":
-			output[logger.MsgID_JS_DirectEval] = logLevel
-		case "duplicate-case":
-			output[logger.MsgID_JS_DuplicateCase] = logLevel
-		case "duplicate-object-key":
-			output[logger.MsgID_JS_DuplicateObjectKey] = logLevel
-		case "empty-import-meta":
-			output[logger.MsgID_JS_EmptyImportMeta] = logLevel
-		case "equals-nan":
-			output[logger.MsgID_JS_EqualsNaN] = logLevel
-		case "equals-negative-zero":
-			output[logger.MsgID_JS_EqualsNegativeZero] = logLevel
-		case "equals-new-object":
-			output[logger.MsgID_JS_EqualsNewObject] = logLevel
-		case "html-comment-in-js":
-			output[logger.MsgID_JS_HTMLCommentInJS] = logLevel
-		case "impossible-typeof":
-			output[logger.MsgID_JS_ImpossibleTypeof] = logLevel
-		case "private-name-will-throw":
-			output[logger.MsgID_JS_PrivateNameWillThrow] = logLevel
-		case "semicolon-after-return":
-			output[logger.MsgID_JS_SemicolonAfterReturn] = logLevel
-		case "suspicious-boolean-not":
-			output[logger.MsgID_JS_SuspiciousBooleanNot] = logLevel
-		case "this-is-undefined-in-esm":
-			output[logger.MsgID_JS_ThisIsUndefinedInESM] = logLevel
-		case "unsupported-dynamic-import":
-			output[logger.MsgID_JS_UnsupportedDynamicImport] = logLevel
-		case "unsupported-jsx-comment":
-			output[logger.MsgID_JS_UnsupportedJSXComment] = logLevel
-		case "unsupported-regexp":
-			output[logger.MsgID_JS_UnsupportedRegExp] = logLevel
-		case "unsupported-require-call":
-			output[logger.MsgID_JS_UnsupportedRequireCall] = logLevel
-
-		// CSS
-		case "css-syntax-error":
-			output[logger.MsgID_CSS_CSSSyntaxError] = logLevel
-		case "invalid-@charset":
-			output[logger.MsgID_CSS_InvalidAtCharset] = logLevel
-		case "invalid-@import":
-			output[logger.MsgID_CSS_InvalidAtImport] = logLevel
-		case "invalid-@nest":
-			output[logger.MsgID_CSS_InvalidAtNest] = logLevel
-		case "invalid-@layer":
-			output[logger.MsgID_CSS_InvalidAtLayer] = logLevel
-		case "invalid-calc":
-			output[logger.MsgID_CSS_InvalidCalc] = logLevel
-		case "js-comment-in-css":
-			output[logger.MsgID_CSS_JSCommentInCSS] = logLevel
-		case "unsupported-@charset":
-			output[logger.MsgID_CSS_UnsupportedAtCharset] = logLevel
-		case "unsupported-@namespace":
-			output[logger.MsgID_CSS_UnsupportedAtNamespace] = logLevel
-		case "unsupported-css-property":
-			output[logger.MsgID_CSS_UnsupportedCSSProperty] = logLevel
-
-		// Bundler
-		case "different-path-case":
-			output[logger.MsgID_Bundler_DifferentPathCase] = logLevel
-		case "ignored-bare-import":
-			output[logger.MsgID_Bundler_IgnoredBareImport] = logLevel
-		case "ignored-dynamic-import":
-			output[logger.MsgID_Bundler_IgnoredDynamicImport] = logLevel
-		case "import-is-undefined":
-			output[logger.MsgID_Bundler_ImportIsUndefined] = logLevel
-		case "require-resolve-not-external":
-			output[logger.MsgID_Bundler_RequireResolveNotExternal] = logLevel
-
-		// Source maps
-		case "invalid-source-mappings":
-			output[logger.MsgID_SourceMap_InvalidSourceMappings] = logLevel
-		case "sections-in-source-map":
-			output[logger.MsgID_SourceMap_SectionsInSourceMap] = logLevel
-		case "missing-source-map":
-			output[logger.MsgID_SourceMap_MissingSourceMap] = logLevel
-		case "unsupported-source-map-comment":
-			output[logger.MsgID_SourceMap_UnsupportedSourceMapComment] = logLevel
-
-		case "package.json":
-			for i := logger.MsgID_PackageJSON_FIRST; i <= logger.MsgID_PackageJSON_LAST; i++ {
-				output[i] = logLevel
-			}
-
-		case "tsconfig.json":
-			for i := logger.MsgID_TsconfigJSON_FIRST; i <= logger.MsgID_TsconfigJSON_LAST; i++ {
-				output[i] = logLevel
-			}
-
-		default:
-			// Ignore invalid entries since this message id may have
-			// been renamed/removed since when this code was written
-			continue
-		}
+		logger.StringToMsgIDs(k, validateLogLevel(v), output)
 	}
 	return
 }
