@@ -18,16 +18,18 @@ import (
 
 func newBuildOptions() api.BuildOptions {
 	return api.BuildOptions{
-		Loader: make(map[string]api.Loader),
-		Define: make(map[string]string),
-		Banner: make(map[string]string),
-		Footer: make(map[string]string),
+		Banner:      make(map[string]string),
+		Define:      make(map[string]string),
+		Footer:      make(map[string]string),
+		Loader:      make(map[string]api.Loader),
+		LogOverride: make(map[string]api.LogLevel),
 	}
 }
 
 func newTransformOptions() api.TransformOptions {
 	return api.TransformOptions{
-		Define: make(map[string]string),
+		Define:      make(map[string]string),
+		LogOverride: make(map[string]api.LogLevel),
 	}
 }
 
@@ -435,6 +437,26 @@ func parseOptionsImpl(
 				transformOpts.Define[value[:equals]] = value[equals+1:]
 			}
 
+		case strings.HasPrefix(arg, "--log-override:"):
+			value := arg[len("--log-override:"):]
+			equals := strings.IndexByte(value, '=')
+			if equals == -1 {
+				return parseOptionsExtras{}, cli_helpers.MakeErrorWithNote(
+					fmt.Sprintf("Missing \"=\" in %q", arg),
+					"You need to use \"=\" to specify both the message name and the log level. "+
+						"For example, \"--log-override:css-syntax-error=error\" turns all \"css-syntax-error\" log messages into errors.",
+				)
+			}
+			logLevel, err := parseLogLevel(value[equals+1:], arg)
+			if err != nil {
+				return parseOptionsExtras{}, err
+			}
+			if buildOpts != nil {
+				buildOpts.LogOverride[value[:equals]] = logLevel
+			} else {
+				transformOpts.LogOverride[value[:equals]] = logLevel
+			}
+
 		case strings.HasPrefix(arg, "--pure:"):
 			value := arg[len("--pure:"):]
 			if buildOpts != nil {
@@ -660,25 +682,9 @@ func parseOptionsImpl(
 		// Make sure this stays in sync with "PrintErrorToStderr"
 		case strings.HasPrefix(arg, "--log-level="):
 			value := arg[len("--log-level="):]
-			var logLevel api.LogLevel
-			switch value {
-			case "verbose":
-				logLevel = api.LogLevelVerbose
-			case "debug":
-				logLevel = api.LogLevelDebug
-			case "info":
-				logLevel = api.LogLevelInfo
-			case "warning":
-				logLevel = api.LogLevelWarning
-			case "error":
-				logLevel = api.LogLevelError
-			case "silent":
-				logLevel = api.LogLevelSilent
-			default:
-				return parseOptionsExtras{}, cli_helpers.MakeErrorWithNote(
-					fmt.Sprintf("Invalid value %q in %q", value, arg),
-					"Valid values are \"verbose\", \"debug\", \"info\", \"warning\", \"error\", or \"silent\".",
-				)
+			logLevel, err := parseLogLevel(value, arg)
+			if err != nil {
+				return parseOptionsExtras{}, err
 			}
 			if buildOpts != nil {
 				buildOpts.LogLevel = logLevel
@@ -778,6 +784,7 @@ func parseOptionsImpl(
 				"footer":        true,
 				"inject":        true,
 				"loader":        true,
+				"log-override":  true,
 				"out-extension": true,
 				"pure":          true,
 			}
@@ -1342,3 +1349,25 @@ func serveImpl(osArgs []string) error {
 	})
 	return result.Wait()
 }
+
+func parseLogLevel(value string, arg string) (api.LogLevel, *cli_helpers.ErrorWithNote) {
+	switch value {
+	case "verbose":
+		return api.LogLevelVerbose, nil
+	case "debug":
+		return api.LogLevelDebug, nil
+	case "info":
+		return api.LogLevelInfo, nil
+	case "warning":
+		return api.LogLevelWarning, nil
+	case "error":
+		return api.LogLevelError, nil
+	case "silent":
+		return api.LogLevelSilent, nil
+	default:
+		return api.LogLevelSilent, cli_helpers.MakeErrorWithNote(
+			fmt.Sprintf("Invalid value %q in %q", value, arg),
+			"Valid values are \"verbose\", \"debug\", \"info\", \"warning\", \"error\", or \"silent\".",
+		)
+	}
+}
